bayespy.inference.vmp.nodes.stochastic.Stochastic.has_plotter
=============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. automethod:: Stochastic.has_plotter